@@ -19,12 +19,12 @@ import os
 
 import confuse
 
-from .client import NessieClient
-from .conf import build_config
+from pynessie.client import NessieClient
+from pynessie.conf import build_config
 
 __author__ = """Project Nessie"""
 __email__ = "nessie-release-builder@dremio.com"
-__version__ = "0.26.0"
+__version__ = "0.41.0"
 
 
 def get_config(config_dir: str = None, args: dict = None) -> confuse.Configuration:
