@@ -15,15 +15,13 @@
 # limitations under the License.
 #
 """Execute config command from cli."""
-from typing import cast
-from typing import Optional
-from typing import Union
+from typing import Optional, Union, cast
 
 import click
 import confuse
 
-from .config_parser import build_config
-from .io import write_to_file
+from pynessie.conf.config_parser import build_config
+from pynessie.conf.io import write_to_file
 
 
 def process(
